Documentation
¶
Overview ¶
Package rod contains go-rod implementation. It is used to parse a file or URL to the rod Page format.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Option ¶
type Option func(*Config)
func WithLambda ¶
func WithPreferences ¶
func WithUserDataDir ¶
func WithWorkingDir ¶
type Rod ¶
type Rod struct {
// Browser is a rod Browser instance.
Browser *rod.Browser
// LoadTimeout controlls max page load time before context is canceled.
LoadTimeout time.Duration
// PageIdleTime sets the wait time after the page stops receiving requests.
PageIdleTime time.Duration
}
Rod is responsible for browsser operations.
func (*Rod) ByteToPage ¶
ByteToPage converts the binary to a rod Page instance.
Click to show internal directories.
Click to hide internal directories.